@@ -43,9 +43,10 @@ class AMQPClass(object):
         """Execute the RPC command for the frame.
 
         :param pamqp.specification.Frame frame_value: The frame to send
-        :rtype: pamqp.specification.Frame | pamqp.message.Message
+        :rtype: pamqp.specification.Frame or pamqp.message.Message
 
         """
+        LOGGER.debug('Issuing RPC to RabbitMQ: %r', frame_value)
         if self.channel.closed:
             raise exceptions.ChannelClosedException()
         return self.channel.rpc(frame_value)
@@ -168,7 +169,7 @@ class AMQPChannel(StatefulObject):
     def close(self):
         if self.closed:
             if DEBUG:
-                LOGGER.debug('Channel %i bypassing close for already closed %s',
+                LOGGER.debug('Channel %i bypassing close, %s already closed',
                              self._channel_id,
                              self.CLOSE_REQUEST_FRAME.name.split('.')[0])
             return
@@ -220,7 +221,7 @@ class AMQPChannel(StatefulObject):
     def _read_from_queue(self):
         """Check to see if a frame is in the queue and if so, return it
 
-        :rtype: amqp.specification.Frame|None
+        :rtype: amqp.specification.Frame or None
 
         """
         self._check_for_exceptions()
@@ -235,7 +236,7 @@ class AMQPChannel(StatefulObject):
 
         :param pamqp.specification.Frame frame_value: The frame to check
         :param frame_type: The frame(s) to check against
-        :type frame_type: pamqp.specification.Frame|list
+        :type frame_type: pamqp.specification.Frame or list
         :rtype: bool
 
         """
@@ -264,7 +265,7 @@ class AMQPChannel(StatefulObject):
         call the method.
 
         :param frame_type: The name or list of names of the frame type(s)
-        :type frame_type: str|list|pamqp.specification.Frame
+        :type frame_type: str or list or pamqp.specification.Frame
         :rtype: Frame
 
         """
@@ -282,7 +283,8 @@ class AMQPChannel(StatefulObject):
                 LOGGER.debug('Read %r from queue', value)
             if value is not None:
                 if DEBUG:
-                    LOGGER.debug('Expecting %s, received %s', frame_type, value)
+                    LOGGER.debug('Expecting %s, received %s',
+                                 frame_type, value)
                 self._read_queue.task_done()
                 if not frame_type:
                     return value
