@@ -57,9 +57,9 @@ class Connection(base.StatefulObject):
 
         :code:`[scheme]://[username]:[password]@[host]:[port]/[virtual_host]`
 
-    The following example connects to the test virtual host on a RabbitMQ server
-    running at 192.168.1.200 port 5672 as the user "www" and the password
-    rabbitmq:
+    The following example connects to the test virtual host on a RabbitMQ
+    server running at 192.168.1.200 port 5672 as the user "www" and the
+    password rabbitmq:
 
         :code:`amqp://admin192.168.1.200:5672/test`
 
@@ -116,8 +116,8 @@ class Connection(base.StatefulObject):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        """When leaving the context, examine why the context is leaving, if it's
-         an exception or what.
+        """When leaving the context, examine why the context is leaving, if
+        it's an exception or what.
 
         """
         if DEBUG:
@@ -136,9 +136,13 @@ class Connection(base.StatefulObject):
     @property
     def blocked(self):
         """Indicates if the connection is blocked from publishing by RabbitMQ.
+
         This flag indicates communication from RabbitMQ that the connection is
         blocked using the Connection.Blocked RPC notification from RabbitMQ
-        slated to be added in 3.2.
+        that was added in RabbitMQ 3.2.
+
+        @TODO If RabbitMQ version < 3.2, use the HTTP management API to query
+        the value
 
         :rtype: bool
 
@@ -209,7 +213,7 @@ class Connection(base.StatefulObject):
         """Close all the channels that are currently open."""
         for channel_id in self._channels:
             if (self._channels[channel_id].open and
-                not self._channels[channel_id].closing):
+                    not self._channels[channel_id].closing):
                 self._channels[channel_id].close()
 
     def _connect(self):
@@ -239,6 +243,7 @@ class Connection(base.StatefulObject):
         while not self._channel0.open:
             if not self._exceptions.empty():
                 exception = self._exceptions.get()
+                self._io.stop()
                 raise exception
             time.sleep(0.1)
 
@@ -270,8 +275,8 @@ class Connection(base.StatefulObject):
                              'write_queue': self._write_queue})
 
     def _create_message(self, channel_id, method_frame, header_frame, body):
-        """Create a message instance with the channel it was received on and the
-        dictionary of message parts.
+        """Create a message instance with the channel it was received on and
+        the dictionary of message parts.
 
         :param int channel_id: The channel id the message was sent on
         :param pamqp.specification.Frame method_frame: The method frame value
@@ -342,7 +347,7 @@ class Connection(base.StatefulObject):
         """Turn a class or list of classes into a list of class names.
 
         :param expectations: List of classes or class name or class obj
-        :type expectations: list|str|pamqp.specification.Frame
+        :type expectations: list or str or pamqp.specification.Frame
         :rtype: list
 
         """
@@ -359,8 +364,8 @@ class Connection(base.StatefulObject):
         return ['%i:%s' % (channel_id, expectations.name)]
 
     def _process_url(self, url):
-        """Parse the AMQP URL passed in and return the configuration information
-        in a dictionary of values.
+        """Parse the AMQP URL passed in and return the configuration
+        information in a dictionary of values.
 
         The URL format is as follows:
 
@@ -477,7 +482,7 @@ class Connection(base.StatefulObject):
 
         # Close the socket
         if (self._events.is_set(events.SOCKET_OPENED) and
-            not self._events.is_set(events.SOCKET_CLOSED)):
+                not self._events.is_set(events.SOCKET_CLOSED)):
             if DEBUG:
                 LOGGER.debug('Requesting IO socket close')
             self._events.set(events.SOCKET_CLOSE)
